@@ -1,117 +1,74 @@
-class Plus:
+class BinaryOperator:
     def __init__(self, left, right):
         self.left = left
         self.right = right
-        
+
     def __str__(self):
-        return 'Plus('+str(self.left)+','+str(self.right)+')'
-        
+        return '%s(%s, %s)' % (self.__class__.__name__, self.left, self.right)
+
+    def toSympy(self, op):
+        return '(%s%s%s)' % (self.left.toSympy(), op, self.right.toSympy())
+
+class Plus(BinaryOperator):
     def toSympy(self):
-        return '('+ self.left.toSympy() +'+'+ self.right.toSympy() +')' 
-        
-class Divide:
-    def __init__(self, left, right):
-        self.left = left
-        self.right = right
-        
-    def __str__(self):
-        return 'Divide('+str(self.left)+','+str(self.right)+')'        
-        
+        return super().toSympy('+')
+
+class Divide(BinaryOperator):
     def toSympy(self):
-        return '('+ self.left.toSympy() +'/'+ self.right.toSympy() +')' 
-        
-class Times:
-    def __init__(self, left, right):
-        self.left = left
-        self.right = right
-        
-    def __str__(self):
-        return 'Times('+str(self.left)+','+str(self.right)+')'    
-            
+        return super().toSympy('/')
+
+class Times(BinaryOperator):
     def toSympy(self):
-        return '('+ self.left.toSympy() +'*'+ self.right.toSympy() +')' 
-        
-class Minus:
-    def __init__(self, left, right):
-        self.left = left
-        self.right = right
-        
-    def __str__(self):
-        return 'Minus('+str(self.left)+','+str(self.right)+')'
-                
+        return super().toSympy('*')
+
+class Minus(BinaryOperator):
     def toSympy(self):
-        return '('+ self.left.toSympy() +'-'+ self.right.toSympy() +')' 
-        
-class Pow:
-    def __init__(self, left, right):
-        self.left = left
-        self.right = right
-        
-    def __str__(self):
-        return 'Pow('+str(self.left)+','+str(self.right)+')'
-        
+        return super().toSympy('-')
+
+class Pow(BinaryOperator):
     def toSympy(self):
-        return '('+ self.left.toSympy() +'**'+ self.right.toSympy() +')' 
-        
-        
-class Arrow:
-    def __init__(self, left, right):
-        self.left = left
-        self.right = right
-        
-    def __str__(self):
-        return 'Arrow('+str(self.left)+','+str(self.right)+')'
-                
+        return super().toSympy('**')
+
+class Arrow(BinaryOperator):
     def toSympy(self):
-        return self.left.toSympy() + ',' + self.right.toSympy()
-        
-class Eq:
-    def __init__(self, left, right):
-        self.left = left
-        self.right = right
-        
-    def __str__(self):
-        return 'Eq('+str(self.left)+','+str(self.right)+')'
-                
+        return '%s,%s' % (self.left.toSympy(), self.right.toSympy())
+
+class Eq(BinaryOperator):
     def toSympy(self):
-        return '('+self.left.toSympy() + '-' + self.right.toSympy()+')'
-        
-        
-class Opp:
+        return super().toSympy('-')
+
+
+
+class UnaryOperator:
     def __init__(self, val):
         self.val = val
-        
+
     def __str__(self):
-        return 'Opp('+str(self.val)+')'
-                
+        return '%s(%s)' % (self.__class__.__name__, self.val)
+
+class Opp(UnaryOperator):
     def toSympy(self):
-        return '('+ '-' + self.val.toSympy() +')' 
-        
-class Fact:
-    def __init__(self, val):
-        self.val = val
-        
-    def __str__(self):
-        return 'Fact('+str(self.val)+')'
-                
+        return '('+ '-' + self.val.toSympy() +')'
+
+class Fact(UnaryOperator):
     def toSympy(self):
-        return '(' + self.val.toSympy() +'!)' 
-        
+        return '(' + self.val.toSympy() +'!)'
+
 class Diff:
     def __init__(self, val, nb):
         self.val = val
         self.nb=nb
-        
+
     def __str__(self):
         return 'Diff('+str(self.val)+','+str(self.nb)+')'
-        
+
     def toSympy(self):
-        return 'Derivative('+self.val.toSympy()+','+self.val.args[0].toSympy()+','+str(self.nb)+')'
-        
+        return 'diff('+self.val.toSympy()+','+self.val.args[0].toSympy()+','+str(self.nb)+')'
+
 class List:
     def __init__(self, l):
         self.list = l
-        
+
     def __str__(self):
         if len(self.list)==0:
             return 'List([])'
@@ -119,19 +76,19 @@ class List:
         for e in self.list[1:]:
             s = s + ', ' + str(e)
         return s+'])'
-        
+
     def __getitem__(self,index):
         return self.list[index]
-        
+
     def __add__(self, other):
         return List(self.list+other.list)
-        
+
     def __len__(self):
         return len(self.list)
-        
+
     def getList(self):
         return self.list
-        
+
     def toSympy(self):
         if len(self.list)==0:
             return ''
@@ -139,19 +96,19 @@ class List:
         for e in self.list[1:]:
             s = s + ', ' + e.toSympy()
         return s
-        
+
 class FunctionCall:
     def __init__(self, function, args):
         self.function = function
         self.args = args
-        
+
     def __str__(self):
         return 'FunctionCall('+str(self.function)+','+str(self.args)+')'
-                
+
     def toSympy(self):
         if type(self.function)==Id:
             return self.translate(self.function.toSympy(), self.args)
-            
+
     def translate(self, function, args):
         mathematicaToSympy={'Sqrt' : (lambda a: 'sqrt('+a[0].toSympy()+')'),
                             'Sin' : (lambda a: 'sin('+a[0].toSympy()+')'),
@@ -178,20 +135,22 @@ class FunctionCall:
                             'Solve' : (lambda a: 'solve(['+a[0].toSympy() +'],['+ a[1].toSympy()+'])'),
                            }
 
-        if function in mathematicaToSympy.keys():
-            return '('+mathematicaToSympy[function](args)+')'
+        for name in mathematicaToSympy.keys():
+            if name == function:
+                return '('+mathematicaToSympy[name](args)+')'
+
         return '('+function+'('+ self.args.toSympy() +')'+')'
-        
+
 class Id:
     def __init__(self, id):
         self.id=id
-    
+
     def __str__(self):
         return 'Id('+str(self.id)+')'
-        
+
     def toSympy(self):
         return self.translateId(self.id)
-        
+
     def translateId(self, id):
         mathematicaToSympy={'Infinity' : 'oo',
                             'I' : 'I',
