@@ -1,13 +1,14 @@
 """Request handler of the module."""
 
-from ppp_datamodel import Sentence, Resource
+from ppp_datamodel import Sentence
+from ppp_datamodel.nodes.resource import MathLatexResource
 from ppp_datamodel.communication import TraceItem, Response, Request
 from ppp_libmodule.exceptions import ClientError
 from sympy import count_ops, latex
 from sympy.parsing.sympy_parser import parse_expr
 
 from .evaluator import evaluate
-from .notation import relevance, isMath, traceContainsSpellChecker
+from .notation import relevance, isMath, traceContainsSpellChecker, isInteresting
 
 class RequestHandler:
     def __init__(self, request):
@@ -20,14 +21,18 @@ class RequestHandler:
         if not isinstance(self.tree, Sentence):
             return []
 
-        if not isMath(self.tree.value) or traceContainsSpellChecker(self.trace):
+        mathNotation = isMath(self.tree.value) 
+        if mathNotation == 0 or traceContainsSpellChecker(self.trace):
             return []
 
-        outputFormula=evaluate(self.tree.value)
-        outputTree=Resource(latex(outputFormula), value_type='math-latex')
+        outputString, outputLatex=evaluate(self.tree.value)
+        if not isInteresting(str(self.tree.value), outputString) and mathNotation == 1:
+            return []
+
+        outputTree=MathLatexResource(outputString, latex=outputLatex)
         measures = {
             'accuracy': 1,
-            'relevance': relevance(self.tree.value, outputFormula)
+            'relevance': relevance(self.tree.value, outputString)
         }
         trace = self.trace + [TraceItem('CAS', outputTree, measures)]
         response = Response(self.language, outputTree, measures, trace)
